@@ -44,7 +44,6 @@ static struct recovery_info_t {
 	gint numdiscards;
 	gboolean rolled_dice;
 	gint die1, die2;
-	gboolean played_develop;
 	gboolean bought_develop;
 	GList *build_list;
 	gboolean ship_moved;
@@ -189,8 +188,8 @@ static void dummy_start_game(void)
 {;
 }
 
-static void dummy_setup(G_GNUC_UNUSED unsigned num_settlements,
-			G_GNUC_UNUSED unsigned num_roads)
+static void dummy_setup(G_GNUC_UNUSED gint num_settlements,
+			G_GNUC_UNUSED gint num_roads)
 {;
 }
 
@@ -308,7 +307,7 @@ static void dummy_bought_develop(G_GNUC_UNUSED DevelType type)
 }
 
 static void dummy_played_develop(G_GNUC_UNUSED gint player_num,
-				 G_GNUC_UNUSED gint card_idx,
+				 G_GNUC_UNUSED guint card_idx,
 				 G_GNUC_UNUSED DevelType type)
 {;
 }
@@ -332,8 +331,8 @@ static void dummy_robber(void)
 
 static void dummy_robber_moved(G_GNUC_UNUSED Hex * old,
 			       G_GNUC_UNUSED Hex * new)
-{
-};
+{;
+}
 
 static void dummy_steal_building(void)
 {;
@@ -647,7 +646,9 @@ static gboolean check_other_players(StateMachine * sm)
 	BuildType build_type;
 	DevelType devel_type;
 	Resource resource_type, supply_type, receive_type;
-	gint player_num, victim_num, card_idx, backwards;
+	gint player_num, victim_num;
+	guint card_idx;
+	gint backwards;
 	gint discard_num, num, ratio, die1, die2, x, y, pos;
 	gint id;
 	gint resource_list[NO_RESOURCE], wanted_list[NO_RESOURCE];
@@ -739,7 +740,7 @@ static gboolean check_other_players(StateMachine * sm)
 		develop_bought(player_num);
 		return TRUE;
 	}
-	if (sm_recv(sm, "play-develop %d %D", &card_idx, &devel_type)) {
+	if (sm_recv(sm, "play-develop %u %D", &card_idx, &devel_type)) {
 		develop_played(player_num, card_idx, devel_type);
 		return TRUE;
 	}
@@ -747,6 +748,12 @@ static gboolean check_other_players(StateMachine * sm)
 		turn_begin(player_num, num);
 		return TRUE;
 	}
+	if (sm_recv(sm, "shuffled-dice-deck")) {
+		/* %s = Player name */
+		log_message(MSG_DICE, _("%s shuffled the dice deck.\n"),
+			    player_name(player_num, TRUE));
+		return TRUE;
+	}
 	if (sm_recv(sm, "rolled %d %d", &die1, &die2)) {
 		turn_rolled_dice(player_num, die1, die2);
 		if (die1 + die2 != 7)
@@ -943,7 +950,8 @@ gboolean mode_start(StateMachine * sm, gint event)
 	if (event != SM_RECV)
 		return FALSE;
 	if (sm_recv(sm, "version report")) {
-		sm_send(sm, "version %s\n", PROTOCOL_VERSION);
+		sm_send(sm, "version %s\n",
+			client_version_type_to_string(LATEST_VERSION));
 		return TRUE;
 	}
 	if (sm_recv(sm, "status report")) {
@@ -1046,7 +1054,6 @@ static gboolean mode_load_game(StateMachine * sm, gint event)
 		recovery_info.rolled_dice = FALSE;
 		recovery_info.die1 = -1;
 		recovery_info.die2 = -1;
-		recovery_info.played_develop = FALSE;
 		recovery_info.bought_develop = FALSE;
 		recovery_info.build_list = NULL;
 		recovery_info.ship_moved = FALSE;
@@ -1138,10 +1145,6 @@ static gboolean mode_load_gameinfo(StateMachine * sm, gint event)
 	     &recovery_info.die2)) {
 		return TRUE;
 	}
-	if (sm_recv(sm, "played develop")) {
-		recovery_info.played_develop = TRUE;
-		return TRUE;
-	}
 	if (sm_recv(sm, "moved ship")) {
 		recovery_info.ship_moved = TRUE;
 		return TRUE;
@@ -1174,7 +1177,7 @@ static gboolean mode_load_gameinfo(StateMachine * sm, gint event)
 			return FALSE;
 		}
 
-		develop_bought_card_turn(devcard, devcardturnbought);
+		develop_bought_card_turn(devcard, devcardturnbought != 0);
 
 		devcardidx++;
 		if (devcardidx >= numdevcards) {
@@ -1445,7 +1448,7 @@ static char *setup_msg(void)
 
 static gboolean mode_setup(StateMachine * sm, gint event)
 {
-	unsigned total;
+	gint total;
 	sm_state_name(sm, "mode_setup");
 	switch (event) {
 	case SM_ENTER:
@@ -1841,7 +1844,7 @@ static gboolean mode_year_of_plenty(StateMachine * sm, gint event)
  */
 gboolean mode_play_develop_response(StateMachine * sm, gint event)
 {
-	gint card_idx;
+	guint card_idx;
 	DevelType card_type;
 
 	sm_state_name(sm, "mode_play_develop_response");
@@ -1851,7 +1854,7 @@ gboolean mode_play_develop_response(StateMachine * sm, gint event)
 		break;
 	case SM_RECV:
 		if (sm_recv
-		    (sm, "play-develop %d %D", &card_idx, &card_type)) {
+		    (sm, "play-develop %u %D", &card_idx, &card_type)) {
 			build_clear();
 			waiting_for_network(FALSE);
 			develop_played(my_player_num(), card_idx,
@@ -1949,6 +1952,12 @@ gboolean mode_roll_response(StateMachine * sm, gint event)
 	case SM_ENTER:
 		waiting_for_network(TRUE);
 		break;
+		if (sm_recv(sm, "shuffled-dice-deck")) {
+			log_message(MSG_DICE,
+				    _("%s shuffled the dice deck.\n"),
+				    player_name(my_player_num(), TRUE));
+			return TRUE;
+		}
 	case SM_RECV:
 		if (sm_recv(sm, "rolled %d %d", &die1, &die2)) {
 			turn_rolled_dice(my_player_num(), die1, die2);
@@ -2512,6 +2521,7 @@ static void recover_from_disconnect(StateMachine * sm,
 {
 	StateFunc modeturn;
 	GList *next;
+	guint num_playable_cards = get_num_playable_cards();
 
 	callbacks.start_game();
 	if (rinfo->turnnum > 0)
@@ -2529,9 +2539,9 @@ static void recover_from_disconnect(StateMachine * sm,
 	else
 		modeturn = mode_turn;
 
-	if (rinfo->played_develop || rinfo->bought_develop) {
-		develop_reset_have_played_bought(rinfo->played_develop,
-						 rinfo->bought_develop);
+	if (rinfo->bought_develop) {
+		develop_reset_have_played_bought(rinfo->bought_develop,
+						 num_playable_cards);
 	}
 
 	/* setup_begin must be called before the build list is created,
