@@ -32,27 +32,28 @@
 #include "state.h"
 #include "callback.h"
 
-static gboolean played_develop;	/* already played a non-victory card? */
 static gboolean bought_develop;	/* have we bought a development card? */
+static guint num_playable_cards;	/* number of playable development cards */
 
 static gboolean is_unique[NUM_DEVEL_TYPES];	/* is each card unique? */
 
-static DevelDeck *develop_deck;	/* our deck of development cards */
+static Deck *develop_deck;	/* our deck of development cards */
 
 void develop_init(void)
 {
 	int idx;
 	if (develop_deck != NULL)
-		deck_free(develop_deck);
-	develop_deck = deck_new(game_params);
+		deck_free(develop_deck, NULL);
+	develop_deck = deck_new();
+	num_playable_cards = 0;
 	for (idx = 0; idx < NUM_DEVEL_TYPES; idx++)
 		is_unique[idx] = game_params->num_develop_type[idx] == 1;
 }
 
-void develop_bought_card_turn(DevelType type, gint turnbought)
+void develop_bought_card_turn(DevelType type, gboolean bought_this_turn)
 {
-	deck_card_add(develop_deck, type, turnbought);
-	if (turnbought == turn_num()) {
+	deck_add_guint(develop_deck, type);
+	if (bought_this_turn) {
 		/* Cannot undo build after buying a development card
 		 */
 		build_clear();
@@ -72,7 +73,9 @@ void develop_bought_card_turn(DevelType type, gint turnbought)
 				    _(""
 				      "You bought a %s development card.\n"),
 				    get_devel_name(type));
-	};
+	} else {
+		num_playable_cards++;
+	}
 	player_modify_statistic(my_player_num(), STAT_DEVELOPMENT, 1);
 	stock_use_develop();
 	callbacks.bought_develop(type);
@@ -80,14 +83,19 @@ void develop_bought_card_turn(DevelType type, gint turnbought)
 
 void develop_bought_card(DevelType type)
 {
-	develop_bought_card_turn(type, turn_num());
+	develop_bought_card_turn(type, TRUE);
 }
 
-void develop_reset_have_played_bought(gboolean have_played,
-				      gboolean have_bought)
+guint get_num_playable_cards(void)
+{
+	return num_playable_cards;
+}
+
+void develop_reset_have_played_bought(gboolean have_bought,
+				      guint number_playable_cards)
 {
-	played_develop = have_played;
 	bought_develop = have_bought;
+	num_playable_cards = number_playable_cards;
 }
 
 void develop_bought(gint player_num)
@@ -99,13 +107,12 @@ void develop_bought(gint player_num)
 	stock_use_develop();
 }
 
-void develop_played(gint player_num, gint card_idx, DevelType type)
+void develop_played(gint player_num, guint card_idx, DevelType type)
 {
 	if (player_num == my_player_num()) {
-		deck_card_play(develop_deck,
-			       played_develop, card_idx, turn_num());
+		deck_card_play(develop_deck, num_playable_cards, card_idx);
 		if (!is_victory_card(type))
-			played_develop = TRUE;
+			num_playable_cards = 0;
 	}
 	callbacks.played_develop(player_num, card_idx, type);
 
@@ -191,17 +198,15 @@ void monopoly_player(gint player_num, gint victim_num, gint num,
 
 void develop_begin_turn(void)
 {
-	played_develop = FALSE;
 	bought_develop = FALSE;
+	num_playable_cards = deck_count(develop_deck);
 }
 
-gboolean can_play_develop(gint card)
+gboolean can_play_develop(guint card)
 {
-	if (card < 0
-	    || !deck_card_playable(develop_deck, played_develop, card,
-				   turn_num()))
+	if (!deck_card_playable(develop_deck, num_playable_cards, card))
 		return FALSE;
-	if (deck_card_type(develop_deck, card) == DEVEL_ROAD_BUILDING
+	if (deck_get_guint(develop_deck, card) == DEVEL_ROAD_BUILDING
 	    && !road_building_can_build_road()
 	    && !road_building_can_build_ship()
 	    && !road_building_can_build_bridge())
@@ -212,8 +217,8 @@ gboolean can_play_develop(gint card)
 
 gboolean can_play_any_develop(void)
 {
-	int i;
-	for (i = 0; i < develop_deck->num_cards; ++i)
+	guint i;
+	for (i = 0; i < deck_count(develop_deck); ++i)
 		if (can_play_develop(i))
 			return TRUE;
 	return FALSE;
@@ -230,7 +235,7 @@ gboolean have_bought_develop(void)
 	return bought_develop;
 }
 
-const DevelDeck *get_devel_deck(void)
+const Deck *get_devel_deck(void)
 {
 	return develop_deck;
 }
