@@ -74,7 +74,8 @@ void gold_choose_player_must(gint num, const gint * bank)
 						      GTK_WINDOW
 						      (app_window),
 						      GTK_DIALOG_DESTROY_WITH_PARENT,
-						      GTK_STOCK_OK,
+						      /* Button text */
+						      _("_OK"),
 						      GTK_RESPONSE_OK,
 						      NULL);
 	g_signal_connect(G_OBJECT(gold.dlg), "destroy",
