@@ -47,6 +47,21 @@ static GuiState previous_state = dummy_state;
 
 static gboolean discard_busy = FALSE, robber_busy = FALSE;
 
+static GtkWidget *game_over_dlg = NULL;
+
+void frontend_init_game(void)
+{
+	notification_close();
+	player_clear_summary();
+	chat_clear_names();
+	develop_reset();
+	histogram_reset();
+	gui_reset();
+	if (game_over_dlg != NULL) {
+		gtk_widget_destroy(game_over_dlg);
+	}
+}
+
 static void frontend_state_idle(G_GNUC_UNUSED GuiEvent event)
 {
 	/* don't react on any event when idle. */
@@ -646,7 +661,10 @@ void frontend_game_over(gint player, gint points)
 		robber_busy = FALSE;
 		gui_prompt_hide();
 	}
-	gameover_create_dlg(player, points);
+	game_over_dlg = gameover_create_dlg(player, points);
+	g_signal_connect(G_OBJECT(game_over_dlg), "destroy",
+			 G_CALLBACK(gtk_widget_destroyed), &game_over_dlg);
+	notification_close();
 	set_gui_state(frontend_state_idle);
 }
 
@@ -655,6 +673,7 @@ void frontend_rolled_dice(gint die1, gint die2, gint player_num)
 	histogram_dice_rolled(die1 + die2, player_num);
 	identity_set_dice(die1, die2);
 	gui_highlight_chits(die1 + die2);
+	notification_close();
 	frontend_gui_update();
 }
 
@@ -689,7 +708,7 @@ static gboolean can_building_be_robbed(MapElement node,
 				       G_GNUC_UNUSED int owner,
 				       MapElement robber)
 {
-	gint idx;
+	guint idx;
 
 	/* Can only steal from buildings that are not owned by me */
 	if (node.node->type == BUILD_NONE
@@ -712,7 +731,7 @@ static gboolean can_edge_be_robbed(MapElement edge,
 				   G_GNUC_UNUSED int owner,
 				   MapElement pirate)
 {
-	gint idx;
+	guint idx;
 
 	/* Can only steal from ships that are not owned by me */
 	if (edge.edge->type != BUILD_SHIP
@@ -873,14 +892,15 @@ static void frontend_mode_setup(GuiEvent event)
 		cb_end_turn();
 		gui_cursor_none();	/* Finish single click build */
 		set_gui_state(frontend_state_idle);
+		notification_close();
 		return;
 	default:
 		break;
 	}
 }
 
-void frontend_setup(G_GNUC_UNUSED unsigned num_settlements,
-		    G_GNUC_UNUSED unsigned num_roads)
+void frontend_setup(G_GNUC_UNUSED gint num_settlements,
+		    G_GNUC_UNUSED gint num_roads)
 {
 	if (get_gui_state() == frontend_mode_setup) {
 		frontend_gui_update();
