@@ -63,7 +63,8 @@ void plenty_create_dlg(const gint * bank)
 							GTK_WINDOW
 							(app_window),
 							GTK_DIALOG_DESTROY_WITH_PARENT,
-							GTK_STOCK_OK,
+							/* Button text */
+							_("_OK"),
 							GTK_RESPONSE_OK,
 							NULL);
 	g_signal_connect(G_OBJECT(plenty.dlg), "destroy",
