@@ -163,7 +163,7 @@ static void allocate_resources(Player * player, BuildRec * rec)
 	Game *game = player->game;
 	Map *map = game->params->map;
 	Node *node;
-	gint idx;
+	guint idx;
 
 	node = map_node(map, rec->x, rec->y, rec->pos);
 
@@ -298,7 +298,7 @@ gboolean mode_setup(Player * player, gint event)
 static void try_start_game(Game * game)
 {
 	GList *list;
-	int num;
+	guint num;
 	int numturn;
 
 	num = 0;
@@ -329,7 +329,7 @@ static void try_start_game(Game * game)
 	if (num != game->params->num_players)
 		return;
 
-	if (game_is_unstartable(game)) {
+	if (params_game_is_unstartable(game->params)) {
 		/* this game cannot be started, don't enter the setup phase */
 		return;
 	}
@@ -395,7 +395,7 @@ static void send_game_line(gpointer player, const gchar * str)
 
 gboolean send_gameinfo_uncached(const Hex * hex, void *data)
 {
-	gint i;
+	guint i;
 	Player *player = data;
 
 	for (i = 0; i < G_N_ELEMENTS(hex->nodes); i++) {
@@ -490,7 +490,7 @@ gboolean mode_pre_game(Player * player, gint event)
 	Map *map = game->params->map;
 	StateFunc state;
 	const gchar *prevstate;
-	gint i;
+	guint i;
 	GList *next;
 	gint longestroadpnum = -1;
 	gint largestarmypnum = -1;
@@ -597,11 +597,6 @@ gboolean mode_pre_game(Player * player, gint event)
 						     game->die1,
 						     game->die2);
 			}
-			if (game->played_develop) {
-				player_send_uncached(player, FIRST_VERSION,
-						     LATEST_VERSION,
-						     "played develop\n");
-			}
 			if (game->bought_develop) {
 				player_send_uncached(player, FIRST_VERSION,
 						     LATEST_VERSION,
@@ -687,17 +682,27 @@ gboolean mode_pre_game(Player * player, gint event)
 			player_send_uncached(player, FIRST_VERSION,
 					     LATEST_VERSION,
 					     "playerinfo: numdevcards: %d\n",
-					     player->devel->num_cards);
-			for (i = 0; i < player->devel->num_cards; i++) {
-				player_send_uncached(player,
-						     FIRST_VERSION,
+					     deck_count(player->devel));
+			for (i = 0; i < deck_count(player->devel); i++) {
+				player_send_uncached(player, FIRST_VERSION,
+						     V14,
+						     "playerinfo: devcard: %d %d\n",
+						     (gint)
+						     deck_get_guint
+						     (player->devel, i),
+						     i <
+						     game->num_playable_cards
+						     ? -1 : game->
+						     curr_turn);
+				player_send_uncached(player, V15,
 						     LATEST_VERSION,
 						     "playerinfo: devcard: %d %d\n",
-						     (gint) player->
-						     devel->cards[i].type,
-						     player->
-						     devel->cards[i].
-						     turn_bought);
+						     (gint)
+						     deck_get_guint
+						     (player->devel, i),
+						     i <
+						     game->num_playable_cards
+						     ? 0 : 1);
 			}
 			player_send_uncached(player, V14,
 					     LATEST_VERSION,
@@ -766,7 +771,7 @@ gboolean mode_pre_game(Player * player, gint event)
 						     LATEST_VERSION,
 						     "otherplayerinfo: %d %d %d %d %d %d %d %d %d %d %d\n",
 						     p->num, numassets,
-						     p->devel->num_cards,
+						     deck_count(p->devel),
 						     p->num_soldiers,
 						     p->chapel_played,
 						     p->univ_played,
@@ -935,8 +940,19 @@ gboolean mode_pre_game(Player * player, gint event)
 					 * dropped when the cache is sent */
 					sm_goto(sm, (StateFunc)
 						mode_spectator);
-				else
-					sm_pop(sm);
+				else {
+					if (sm_stack_inspect(sm, 1) !=
+					    NULL) {
+						sm_pop(sm);
+					} else {
+						/* During the previous
+						 * connection attempt, the
+						 * connection was lost too
+						 * soon */
+						sm_goto(sm, (StateFunc)
+							mode_idle);
+					}
+				}
 			} else {
 				if (!player_is_spectator
 				    (game, player->num))
